@@ -232,7 +232,7 @@ class OccupationInsightRequestClient(InsightRequest):
 class OccupationInsight:
 
     def __init__(self,
-                 url: str = "https://solutions-api.lightcast.io/smart-dataset/occupation-insight/v1",
+                 url: str = "https://solutions-api.lightcast.io/smart-dataset/occupation-insight/v1/uk",
                  auth_url: str = "https://solutions-api.lightcast.io/api/users/login",
                  username: str = "",
                  password: str = "",
